local _G = _G
local Cartographer3 = _G.Cartographer3
local Cartographer3_Data = Cartographer3.Data

local pois = {}

local function makePoi()
	local poi = CreateFrame("Frame", Cartographer3_Data.mapView:GetName() .. "_Poi" .. (#pois + 1), Cartographer3_Data.mapView)
	pois[#pois+1] = poi
	Cartographer3.AddPOI(poi)
	function poi:AddDataToFullTooltip()
		WorldMapTooltip:SetText(self.name)
		WorldMapTooltip:AddLine(self.description, nil, nil, nil, true)
	end
	function poi:AddDataToTooltipLine()
		WorldMapTooltip:SetText(self.name)
	end
	poi:SetWidth(1)
	poi:SetHeight(1)

	local texture = poi:CreateTexture(nil--[[poi:GetName() .. "_Texture"]], "BACKGROUND");
	poi.texture = texture
	texture:SetAllPoints(poi)
	texture:SetTexture([=[Interface\Minimap\POIIcons]=])
	
	return poi
end

local function f()
	Cartographer3.Utils.RemoveTimer(f)
	
	local numPois = GetNumMapLandmarks()
	
	for i = 1, numPois do
		local poi = pois[i] or makePoi()
		
		local name, description, textureIndex, x, y = GetMapLandmarkInfo(i)
		if textureIndex ~= 15 then
			local x1, x2, y1, y2 = WorldMap_GetPOITextureCoords(textureIndex)
			poi.texture:SetTexCoord(
				(textureIndex % 8) / 8,
				((textureIndex % 8) + 1) / 8,
				math.floor(textureIndex / 8) / 8,
				(math.floor(textureIndex / 8) + 1) / 8)
		
			local poiX, poiY = Cartographer3.Utils.ConvertZoneCoordinateToUniverseCoordinate(Cartographer3_Data.currentMapTexture, x, y)
			poi:SetPoint("CENTER", Cartographer3_Data.mapView, "CENTER", poiX, poiY)
			poi.name = name
			poi.description = description
			poi:Show()
		else
			poi:Hide()
		end
	end
	for i = numPois+1, #pois do
		pois[i]:Hide()
	end
end

Cartographer3.Utils.AddEventListener("WORLD_MAP_UPDATE", function(event)
	Cartographer3.Utils.AddTimer(f)
end)
